@@ -1,8 +1,10 @@
-use std::collections::{BTreeMap, HashMap};
+use std::collections::HashMap;
 use std::fmt::Display;
 use std::hash::Hash;
 use std::str::FromStr;
 
+use indexmap::IndexMap;
+
 use crate::{
     InputType, InputValueError, InputValueResult, Name, OutputType, Scalar, ScalarType, Value,
 };
@@ -34,7 +36,7 @@ where
     }
 
     fn to_value(&self) -> Value {
-        let mut map = BTreeMap::new();
+        let mut map = IndexMap::new();
         for (name, value) in self {
             map.insert(Name::new(name.to_string()), value.to_value());
         }
